@@ -1,11 +1,11 @@
 /*
  *	socketLayer.c
- *	Release $Name: MATRIXSSL_1_8_OPEN $
+ *	Release $Name: MATRIXSSL_1_8_3_OPEN $
  *
  *	Sample SSL socket layer for MatrixSSL example exectuables
  */
 /*
- *	Copyright (c) PeerSec Networks, 2002-2006. All Rights Reserved.
+ *	Copyright (c) PeerSec Networks, 2002-2007. All Rights Reserved.
  *	The latest version of this code is available at http://www.matrixssl.org
  *
  *	This software is open source; you can redistribute it and/or modify
@@ -253,7 +253,7 @@ int sslConnect(sslConn_t **cpp, SOCKET fd, sslKeys_t *keys,
 		sslFreeConnection(&conn);
 		return -1;
 	}
-	matrixSslSetCertValidator(conn->ssl, certValidator, NULL);
+	matrixSslSetCertValidator(conn->ssl, certValidator, keys);
 
 	*cpp = sslDoHandshake(conn, cipherSuite);
 	
