@@ -1,11 +1,11 @@
 /*
  *	des3.c
- *	Release $Name: MATRIXSSL_1_8_OPEN $
+ *	Release $Name: MATRIXSSL_1_8_3_OPEN $
  *
  *	3DES block cipher implementation for low memory usage
  */
 /*
- *	Copyright (c) PeerSec Networks, 2002-2006. All Rights Reserved.
+ *	Copyright (c) PeerSec Networks, 2002-2007. All Rights Reserved.
  *	The latest version of this code is available at http://www.matrixssl.org
  *
  *	This software is open source; you can redistribute it and/or modify
@@ -238,7 +238,7 @@ static void deskey(const unsigned char *key, short edf, ulong32 *keyout);
 
 /******************************************************************************/
 /*
-	Init the 3DES block cipher context for EDE mode.
+	Init the 3DES block cipher context for CBC-EDE mode.
 	IV should point to 8 bytes of initialization vector
 	Key should point to 24 bytes of data
 */
@@ -609,6 +609,24 @@ int32 des3_setup(const unsigned char *key, int32 keylen, int32 num_rounds,
 	return CRYPT_OK;
 }
 
+int des_setup(const unsigned char *key, int keylen, int num_rounds,
+				des3_CBC *skey)
+{
+
+    if (num_rounds != 0 && num_rounds != 16) {
+        return CRYPT_INVALID_ROUNDS;
+    }
+
+    if (keylen != 8) {
+        return CRYPT_INVALID_KEYSIZE;
+    }
+
+    deskey(key, EN0, skey->key.ek[0]);
+    deskey(key, DE1, skey->key.dk[0]);
+
+    return CRYPT_OK;
+}
+
 void des3_ecb_encrypt(const unsigned char *pt, unsigned char *ct, 
 							 des3_CBC *key)
 {
@@ -623,6 +641,18 @@ void des3_ecb_encrypt(const unsigned char *pt, unsigned char *ct,
 	STORE32H(work[1],ct+4);
 }
 
+void des_ecb_encrypt(const unsigned char *pt, unsigned char *ct,
+							des3_CBC *key)
+{
+    ulong32 work[2];
+
+    LOAD32H(work[0], pt+0);
+    LOAD32H(work[1], pt+4);
+    desfunc(work, key->key.ek[0]);
+    STORE32H(work[0],ct+0);
+    STORE32H(work[1],ct+4);
+}
+
 void des3_ecb_decrypt(const unsigned char *ct, unsigned char *pt, 
 							 des3_CBC *key)
 {
@@ -637,6 +667,17 @@ void des3_ecb_decrypt(const unsigned char *ct, unsigned char *pt,
 	STORE32H(work[1],pt+4);
 }
 
+void des_ecb_decrypt(const unsigned char *ct, unsigned char *pt,
+							des3_CBC *key)
+{
+    ulong32 work[2];
+    LOAD32H(work[0], ct+0);
+    LOAD32H(work[1], ct+4);
+    desfunc(work, key->key.dk[0]);
+    STORE32H(work[0],pt+0);
+    STORE32H(work[1],pt+4);
+}
+
 int32 des3_keysize(int32 *desired_keysize)
 {
     if(*desired_keysize < 24) {
@@ -688,7 +729,6 @@ void generate3DESKey(unsigned char *pass, int32 passlen, unsigned char *salt,
 }
 
 
-
 #ifdef PEERSEC_TEST
 
 int32 matrixDes3Test()
@@ -718,6 +758,35 @@ int32 matrixDes3Test()
 
 	return CRYPT_OK;
 }
+
+int32 matrixDesTest()
+{
+	unsigned char key[8], pt[8], ct[8], tmp[8];
+	des3_CBC skey;
+	int32 x, err;
+
+	for (x = 0; x < 8; x++) {
+		pt[x] = x;
+	}
+
+	for (x = 0; x < 8; x++) {
+		key[x] = x;
+	}
+
+	if ((err = des_setup(key, 8, 0, &skey)) != CRYPT_OK) {
+		return err;
+	}
+
+	des_ecb_encrypt(pt, ct, &skey);
+	des_ecb_decrypt(ct, tmp, &skey);
+
+	if (memcmp(pt, tmp, 8) != 0) {
+		return CRYPT_FAIL_TESTVECTOR;
+	}
+
+	return CRYPT_OK;
+}
+
 #endif /* PEERSEC_TEST */
 
 #endif /* USE_3DES */
