@@ -1,11 +1,11 @@
 /*
  *	sslDecode.c
- *	Release $Name: MATRIXSSL_1_8_OPEN $
+ *	Release $Name: MATRIXSSL_1_8_3_OPEN $
  *
  *	Secure Sockets Layer message decoding
  */
 /*
- *	Copyright (c) PeerSec Networks, 2002-2006. All Rights Reserved.
+ *	Copyright (c) PeerSec Networks, 2002-2007. All Rights Reserved.
  *	The latest version of this code is available at http://www.matrixssl.org
  *
  *	This software is open source; you can redistribute it and/or modify
@@ -95,6 +95,7 @@ decodeMore:
 */
 		return SSL_SUCCESS;
 	}
+
 	if (end - c < SSL2_HEADER_LEN) {
 		return SSL_PARTIAL;
 	}
@@ -158,6 +159,7 @@ decodeMore:
 	if (end - c < ssl->rec.len) {
 		return SSL_PARTIAL;
 	}
+
 /*
 	Make sure we have enough room to hold the decoded record
 */
@@ -411,6 +413,9 @@ decodeMore:
 				SSL_MAX_IGNORED_MESSAGE_COUNT);
 			goto encodeResponse;
 		}
+		if (ssl->ignoredMessageCount > 0) {
+			ssl->ignoredMessageCount--;
+		}
 		out->end = mac;
 		return SSL_PROCESS_DATA;
 	}
@@ -489,9 +494,10 @@ static int32 parseSSLHandshake(ssl_t *ssl, char *inbuf, int32 len)
 #endif /* USE_SERVER_SIDE_SSL */
 
 #ifdef USE_CLIENT_SIDE_SSL
-	int32			sessionIdLen, certMatch, certTypeLen;
-	sslRsaCert_t	*cert, *currentCert, *subjectCert;
-	int32			valid, i, certLen, certChainLen, anonCheck;
+	int32			sessionIdLen, certMatch, certTypeLen, i;
+	sslRsaCert_t	*subjectCert;
+	int32			valid, certLen, certChainLen, anonCheck;
+	sslRsaCert_t	*cert, *currentCert;
 #endif /* USE_CLIENT_SIDE_SSL */
 
 	rc = SSL_SUCCESS;
@@ -514,7 +520,7 @@ parseHandshake:
 			(hsType != SSL_HS_CLIENT_HELLO || ssl->hsState != SSL_HS_DONE)) {
 
 /*
-		A mismatch is also possible in the client authentication case.
+		A mismatch is possible in the client authentication case.
 		The optional CERTIFICATE_REQUEST may be appearing instead of 
 		SERVER_HELLO_DONE.
 */
@@ -573,7 +579,7 @@ parseHandshake:
 	SSLv2:
 		1 byte type
 */
-	if (ssl->rec.majVer == SSL3_MAJ_VER) {
+	if (ssl->rec.majVer >= SSL3_MAJ_VER) {
 		if (end - c < 3) {
 			ssl->err = SSL_ALERT_ILLEGAL_PARAMETER;
 			matrixStrDebugMsg("Invalid length of handshake message\n", NULL);
@@ -611,7 +617,7 @@ parseHandshake:
 	case SSL_HS_CLIENT_HELLO:
 /*
 		First two bytes are the highest supported major and minor SSL versions
-		We support only 3.0 (other options are 2.0 or 3.1)
+		We support only 3.0 (support 3.1 in commercial version)
 */
 		if (end - c < 2) {
 			ssl->err = SSL_ALERT_ILLEGAL_PARAMETER;
@@ -620,9 +626,8 @@ parseHandshake:
 		}
 		ssl->reqMajVer = *c; c++;
 		ssl->reqMinVer = *c; c++;
-
-		if (ssl->reqMajVer == SSL3_MAJ_VER) {
-			ssl->majVer = SSL3_MAJ_VER;
+		if (ssl->reqMajVer >= SSL3_MAJ_VER) {
+			ssl->majVer = ssl->reqMajVer;
 			ssl->minVer = SSL3_MIN_VER;
 
 		} else {
@@ -1183,11 +1188,8 @@ parseHandshake:
 			ssl->hsState = SSL_HS_CERTIFICATE;
 		}
 		break;
-#endif /* USE_CLIENT_SIDE_SSL */
 
-#ifdef USE_CLIENT_SIDE_SSL
 	case SSL_HS_CERTIFICATE: 
-
 		if (end - c < 3) {
 			ssl->err = SSL_ALERT_ILLEGAL_PARAMETER;
 			matrixStrDebugMsg("Invalid Certificate message\n", NULL);
@@ -1387,6 +1389,7 @@ parseHandshake:
 	case SSL_HS_SERVER_KEY_EXCHANGE:
 		ssl->err = SSL_ALERT_UNEXPECTED_MESSAGE;
 		return SSL_ERROR;
+
 	default:
 		ssl->err = SSL_ALERT_UNEXPECTED_MESSAGE;
 		return SSL_ERROR;
